@@ -136,7 +136,7 @@ class ReadonlyWidget(SmartWidgetMixin, Widget):
         if isinstance(value, (list, tuple)):
             out = ', '.join([self._get_value_display(val, request) for val in value])
         else:
-            out = self._get_value_display(value)
+            out = self._get_value_display(value, request)
         return format_html('<p>{}</p>', out)
 
     def _render_readonly_value(self, readonly_value):
@@ -364,7 +364,9 @@ class RestrictedSelectWidgetMixin:
         """
         return (
             not hasattr(self.choices, 'queryset') or
-            self.choices.queryset.count() > settings.FOREIGN_KEY_MAX_SELECBOX_ENTRIES
+            settings.FOREIGN_KEY_MAX_SELECTBOX_ENTRIES == 0 or
+            self.choices.queryset.values('pk')[:settings.FOREIGN_KEY_MAX_SELECTBOX_ENTRIES + 1].count()
+            > settings.FOREIGN_KEY_MAX_SELECTBOX_ENTRIES
         )
 
     def render(self, name, value, attrs=None, renderer=None):
